Getting Started
===============

**nnsight** (/ɛn.saɪt/) is a package for the interpreting and manipulating the internals of deep learning models.

.. _installation:

Installation
------------

To get started with nnsight, install it with ``pip``. 

.. code-block:: console

   pip install nnsight


First Steps
-----------

.. grid:: 2
    :gutter: 2

    .. grid-item-card:: Tutorials
      :link: tutorials
      :link-type: doc

      Check out the :bdg-primary:`tutorials` section for some examples on how to get started with nnsight.

    .. grid-item-card:: Colab
      :link: https://colab.research.google.com/drive/1ASP4LlRqSTuNxdhyJzjaZ-6h2NXpP3uK?usp=drive_link

      If you'd like a more hands on experience, this `Colab <https://colab.research.google.com/drive/1ASP4LlRqSTuNxdhyJzjaZ-6h2NXpP3uK?usp=drive_link>`_ covers some basic features and applied examples of the package.

.. grid:: 2
    :gutter: 2

    .. grid-item-card:: Examples
      :link: https://github.com/JadenFiotto-Kaufman/nnsight/tree/main/examples

      Check out more examples on the package repository.
